==> randovania-4.4.2.tar.gz: randovania-4.4.2/test/game_description/test_pretty_print.py <==
from unittest.mock import patch, MagicMock

import pytest

import randovania
from randovania.game_description import pretty_print, default_database
from randovania.game_description.requirements import RequirementAnd, ResourceRequirement, RequirementTemplate
from randovania.games.game import RandovaniaGame


@pytest.mark.skipif(randovania.is_frozen(), reason="frozen executable doesn't have JSON files")
@pytest.mark.parametrize("game", RandovaniaGame)
def test_committed_human_readable_description(game: RandovaniaGame, tmp_path):
    pretty_print.write_human_readable_game(default_database.game_description_for(game), tmp_path)
    new_files = {f.name: f.read_text("utf-8")
                 for f in tmp_path.glob("*.txt")}

    existing_files = {f.name: f.read_text("utf-8")
                      for f in game.data_path.joinpath("json_data").glob("*.txt")}

    assert new_files == existing_files


@patch("randovania.game_description.pretty_print.pretty_print_requirement")
def test_pretty_print_requirement_array_one_item(mock_print_requirement: MagicMock):
    mock_print_requirement.return_value = ["a", "b"]

    req = MagicMock()
    array = RequirementAnd([req])

    # Run
    result = list(pretty_print.pretty_print_requirement_array(array, 3))

    # Assert
    assert result == ["a", "b"]
    mock_print_requirement.assert_called_once_with(req, 3)


@patch("randovania.game_description.pretty_print.pretty_print_requirement")
def test_pretty_print_requirement_array_combinable(mock_print_requirement: MagicMock, echoes_resource_database):
    mock_print_requirement.return_value = ["a", "b"]

    array = RequirementAnd([
        ResourceRequirement(echoes_resource_database.item[0], 1, False),
        RequirementTemplate("Shoot Sunburst"),
    ])

    # Run
    result = list(pretty_print.pretty_print_requirement_array(array, 3))

    # Assert
    assert result == [(3, "Power Beam and Shoot Sunburst")]
    mock_print_requirement.assert_not_called()

==> randovania-4.5.0.tar.gz: randovania-4.5.0/test/game_description/test_pretty_print.py <==
from unittest.mock import patch, MagicMock

import pytest

import randovania
from randovania.game_description import pretty_print, default_database
from randovania.game_description.requirements.requirement_and import RequirementAnd
from randovania.game_description.requirements.requirement_template import RequirementTemplate
from randovania.game_description.requirements.resource_requirement import ResourceRequirement
from randovania.games.game import RandovaniaGame


@pytest.mark.skipif(randovania.is_frozen(), reason="frozen executable doesn't have JSON files")
@pytest.mark.parametrize("game", RandovaniaGame)
def test_committed_human_readable_description(game: RandovaniaGame, tmp_path):
    pretty_print.write_human_readable_game(default_database.game_description_for(game), tmp_path)
    new_files = {f.name: f.read_text("utf-8")
                 for f in tmp_path.glob("*.txt")}

    existing_files = {f.name: f.read_text("utf-8")
                      for f in game.data_path.joinpath("json_data").glob("*.txt")}

    assert new_files == existing_files


@patch("randovania.game_description.pretty_print.pretty_print_requirement")
def test_pretty_print_requirement_array_one_item(mock_print_requirement: MagicMock):
    mock_print_requirement.return_value = ["a", "b"]

    req = MagicMock()
    array = RequirementAnd([req])

    # Run
    result = list(pretty_print.pretty_print_requirement_array(array, 3))

    # Assert
    assert result == ["a", "b"]
    mock_print_requirement.assert_called_once_with(req, 3)


@patch("randovania.game_description.pretty_print.pretty_print_requirement")
def test_pretty_print_requirement_array_combinable(mock_print_requirement: MagicMock, echoes_resource_database):
    mock_print_requirement.return_value = ["a", "b"]

    array = RequirementAnd([
        ResourceRequirement.simple(echoes_resource_database.item[0]),
        RequirementTemplate("Shoot Sunburst"),
    ])

    # Run
    result = list(pretty_print.pretty_print_requirement_array(array, 3))

    # Assert
    assert result == [(3, "Power Beam and Shoot Sunburst")]
    mock_print_requirement.assert_not_called()
